"""Full Application Hooks.

Application and command hooks for the full application example.
"""

from .application_hooks import ApplicationHooks
from .builtin_command_hooks import BuiltinCommandHooks
